@@ -5,13 +5,13 @@ import pathlib
 class DataPackageServerConstants:
     def __init__(self):
         # http server config
-        self.DATABASE = 'C:\\Users\\natha\\PycharmProjects\\FreeTAKServer\\FreeTAKServer\\controllers\\FreeTAKServerDataPackageDataBase.db'
+        self.DATABASE = 'FreeTAKServerDataPackageDataBase.db'
         self.APIPORT = '8080'
         self.DEFAULTRETURN = 'other'
         self.GET = 'GET'
         self.PUT = 'PUT'
         self.POST = 'POST'
-        self.DATAPACKAGEFOLDER = 'C:\\Users\\natha\\PycharmProjects\\FreeTAKServer\\FreeTAKServer\\controllers\\FreeTAKServerDataPackageFolder'
+        self.DATAPACKAGEFOLDER = 'FreeTAKServerDataPackageFolder'
         self.HTTPDEBUG = False
         self.HTTPMETHODS = ['POST', 'GET', 'PUT']
         self.IP = "0.0.0.0"
